@@ -70,6 +70,16 @@ sub list_downloaders {
     return wantarray ? @downloaders : \@downloaders;
 }
 
+sub get_downloader {
+    my $self = shift;
+    
+    my $name = shift;
+
+    my @downloaders = grep { $_->{'name'} eq $name } $self->list_downloaders();
+    die "No such Downloader named >>$name<<" unless @downloaders;
+    return shift @downloaders;
+}
+
 sub bind {
     my $self = shift;
 
@@ -314,7 +324,7 @@ WWW::Xunlei - Perl API For Official Xunlei Remote API.
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
